@@ -121,10 +121,10 @@ class AmoPartnerCrawler(Crawler):
     CLASS FOR SCRAPING BILLING DATA FROM AMO PARTNER CABINET
     """
 
-    def __init__(self, email: str, password: str):
+    def __init__(self, email: str, password: str, remote: bool):
         self.email = email
         self.password = password
-        super().__init__(url='https://www.amocrm.ru/partners/private/shop/bill')
+        super().__init__(url='https://www.amocrm.ru/partners/private/shop/bill', remote=remote)
 
     @logg_func_execution
     def login(self, email: str, password: str) -> None:
